# PublicationDateV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**year** | [**YearV30Rc2**](YearV30Rc2.md) |  | 
**month** | [**MonthV30Rc2**](MonthV30Rc2.md) |  | [optional] 
**day** | [**DayV30Rc2**](DayV30Rc2.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

